@@ -4,13 +4,53 @@ import sys
 
 from gitgoggles.asciitable import AsciiTable, AsciiCell
 from gitgoggles.git import Repository, TrackingBranch, LocalBranch, PublishedBranch, TrackedBranch
-from gitgoggles.utils import colored, terminal_dimensions
+from gitgoggles.utils import colored, terminal_dimensions, console
+from gitgoggles.progress import handler
 
 TAG_PREFIX = 'codereview--'
 
 def get_status():
     repo = Repository()
 
+    console(colored('# Working Tree: ', 'magenta'))
+    console(colored(repo.branch(), 'cyan'))
+    console(u'\n')
+
+    uncommitted, changed, untracked, stashed = repo.status()
+    if uncommitted or changed or untracked or stashed:
+        table = AsciiTable(['', ''], 2, 0, False, border_characters=[u'', u'', u''])
+
+        if uncommitted:
+            table.add_row([
+                AsciiCell('Uncommitted', 'green'),
+                AsciiCell(str(len(uncommitted)), align='right'),
+                ])
+
+        if changed:
+            table.add_row([
+                AsciiCell('Changed', 'red'),
+                AsciiCell(str(len(changed)), align='right'),
+                ])
+
+        if untracked:
+            table.add_row([
+                AsciiCell('Untracked', 'yellow'),
+                AsciiCell(str(len(untracked)), align='right'),
+                ])
+
+        if stashed:
+            table.add_row([
+                AsciiCell('Stashed', 'cyan'),
+                AsciiCell(str(len(stashed)), align='right'),
+                ])
+
+        table.render()
+
+    console('\n')
+
+    handler.uncapture_stdout()
+    handler.capture_stdout()
+
     if repo.configs.get('gitgoggles.fetch', 'true') != 'false':
         repo.fetch()
 
@@ -67,9 +107,9 @@ def get_status():
 
         if ref.__class__ in (TrackingBranch, LocalBranch, TrackedBranch):
             if codereview_tag not in [ x.name for x in tags ]:
-                review_commits = len(repo.git('log', '--no-merges', '--pretty=format:%H', '%s..%s' % (ref.merge_refspec or '', ref.refspec), split=True))
+                review_commits = len(repo.shell('git', 'log', '--no-merges', '--pretty=format:%H', '%s..%s' % (ref.merge_refspec or '', ref.refspec)).split)
             else:
-                review_commits = len(repo.git('log', '--no-merges', '--pretty=format:%H', '%s..%s' % (codereview_tag, ref.refspec), split=True))
+                review_commits = len(repo.shell('git', 'log', '--no-merges', '--pretty=format:%H', '%s..%s' % (codereview_tag, ref.refspec)).split)
         else:
             review_commits = None
 
@@ -128,7 +168,7 @@ def complete_review():
         repo.fetch()
 
     branch = repo.branch()
-    repo.git('tag', '-a', '%s%s' % (TAG_PREFIX, branch), '-f', '-m', 'creating code review for branch %s' % branch)
+    repo.shell('git', 'tag', '-a', '%s%s' % (TAG_PREFIX, branch), '-f', '-m', 'creating code review for branch %s' % branch)
     print 'Created tag %s%s' % (TAG_PREFIX, branch)
 
 def start_review():
@@ -146,9 +186,9 @@ def start_review():
     cr_tag = '%s%s' % (TAG_PREFIX, branch)
 
     if cr_tag in [ x.name for x in tags ]:
-        repo.git('diff', '-w', '%s..%s' % (cr_tag, branch), join=True)
+        repo.shell('git', 'diff', '-w', '%s..%s' % (cr_tag, branch), join=True)
     else:
-        repo.git('diff', '-w', '%s..%s' % (parent, branch), join=True)
+        repo.shell('git', 'diff', '-w', '%s..%s' % (parent, branch), join=True)
 
 def update_branches():
     repo = Repository()
@@ -160,5 +200,5 @@ def update_branches():
     refs = repo.branches(TrackingBranch)
     for branch in refs:
         if branch.pull:
-            repo.git('checkout', branch.name)
-            repo.git('pull')
+            repo.shell('git', 'checkout', branch.name)
+            repo.shell('git', 'pull')
